==============
Bag of Factors
==============


.. image:: https://img.shields.io/pypi/v/bof.svg
        :target: https://pypi.python.org/pypi/bof
        :alt: PyPI Status

.. image:: https://github.com/balouf/bof/workflows/build/badge.svg?branch=master
        :target: https://github.com/balouf/bof/actions?query=workflow%3Abuild
        :alt: Build Status

.. image:: https://github.com/balouf/bof/workflows/docs/badge.svg?branch=master
        :target: https://github.com/balouf/bof/actions?query=workflow%3Adocs
        :alt: Documentation Status


.. image:: https://codecov.io/gh/balouf/bof/branch/master/graphs/badge.svg
        :target: https://codecov.io/gh/balouf/bof/branch/master/graphs
        :alt: Code Coverage



Bag of Factors allow you to analyze a corpus from its factors.


* Free software: GNU General Public License v3
* Documentation: https://balouf.github.io/bof/.


--------
Features
--------

* TODO

-------
Credits
-------

This package was created with Cookiecutter_ and the `francois-durand/package_helper_2`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`francois-durand/package_helper_2`: https://github.com/francois-durand/package_helper_2
